@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-c7ab180e681ee6773fbc9cbace33c04c
-key: yesod_H5GlsVOADT03djUfKO6kHn
+id: yesod-1.4.2-320e011c17cd5de79d8233919afce0be
+key: yesod_Kn6cmh6It9HISA4cwgdrkd
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-H5GlsVOADT03djUfKO6kHn
+hs-libraries: HSyesod-1.4.2-Kn6cmh6It9HISA4cwgdrkd
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -48,7 +48,7 @@ depends:
     wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
     warp-3.2.3-6de819de378ae4c57281b63b66004254
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.12-45cd7bbc9c204488900d549568a3d042
+    yesod-auth-1.4.12-a6b0c71caf511a065a47faa3af7c7c3f
     yesod-core-1.4.19-83d7786ccf417e9f8ff12c2ba1e4758e
     yesod-form-1.4.6-74e09ec1e0cc3b893c314cc7937841de
     yesod-persistent-1.4.0.3-2e82e69e0978c8663ea0bc70a29c9f56
